@@ -25,6 +25,8 @@ class TemplateRewritingLoader(BaseLoader):
 
         if path.endswith("/material/partials/nav-item.html"):
             src = _transform_material_nav_item_template(src)
+        elif path.endswith("/material/partials/tabs-item.html"):
+            src = _transform_material_tabs_item_template(src)
         elif path.endswith("/themes/readthedocs/base.html"):
             src = _transform_readthedocs_base_template(src)
         else:
@@ -42,7 +44,8 @@ class TemplateRewritingLoader(BaseLoader):
 def _transform_material_nav_item_template(src: str) -> str:
     repl = """\
         {% if nav_item.url %}
-          <a href="{{ nav_item.url | url }}"{% if nav_item == page %} class="md-nav__link--active"{% endif %} style="display: block">
+          <a href="{{ nav_item.url | url }}" class="md-nav__link{% if nav_item == page %} md-nav__link--active{% endif %}"
+            style="margin: initial; padding: initial; pointer-events: initial">
         {% endif %}
           [...]
         {% if nav_item.url %}</a>{% endif %}
@@ -56,6 +59,16 @@ def _transform_material_nav_item_template(src: str) -> str:
     return "\n".join(lines)
 
 
+def _transform_material_tabs_item_template(src: str) -> str:
+    return src.replace(
+        "(nav_item.children | first).url",
+        "(nav_item.url or (nav_item.children | first).url)",
+    ).replace(
+        "if (nav_item.children | first).children",
+        "if (nav_item.children | first).children and not nav_item.url",
+    )
+
+
 def _transform_readthedocs_base_template(src: str) -> str:
     repl = """\
         {% if nav_item.url %}
